@@ -20,5 +20,11 @@ helm_bc_msg = 'In November 2020, Helm 2 reached end of life. ' \
               'then it is stored in a legacy Helm repository and is at risk of deletion.\n' \
               'For more information on managing and deploying applications for Kubernetes, ' \
               'see https://aka.ms/acr/helm.'
+
+content_trust_bc_msg = 'Content Trust is being deprecated and will be completely removed on March 31, 2028. ' \
+                       'Refer to https://aka.ms/acr/dctdeprecation for details and transition guidance'
+
 register_command_group_deprecate(command_group='acr helm', redirect='Helm v3 commands', message=helm_bc_msg,
                                  target_version='Sept 30th, 2025')
+
+register_command_group_deprecate(command_group='acr config content-trust', message=content_trust_bc_msg)
