@@ -340,7 +340,7 @@ def pg_arguments_validator(db_context, location, tier, sku_name, storage_gb, ser
     else:
         supported_storageV2_size = None
     _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_redundant_backup, performance_tier,
-                               supported_storageV2_size, iops, throughput, instance)
+                               tier, supported_storageV2_size, iops, throughput, instance)
     _pg_storage_performance_tier_validator(performance_tier,
                                            sku_info,
                                            tier,
@@ -514,10 +514,14 @@ def _pg_version_validator(version, versions):
     if version:
         if version not in versions:
             raise CLIError('Incorrect value for --version. Allowed values : {}'.format(sorted(versions)))
-        if version == '12':
-            raise CLIError("Support for PostgreSQL 12 has officially ended. "
-                           "We recommend selecting PostgreSQL 13 or a later version for "
-                           "all future operations.")
+        if version in ('11', '12'):
+            logger.warning("Support for PostgreSQL %s has officially ended. "
+                           "We recommend selecting PostgreSQL 14 or a later version for "
+                           "all future operations.", str(version))
+        if version == '13':
+            logger.warning("PostgreSQL version 13 will reach end-of-life (EOL) soon. "
+                           "Upgrade to PostgreSQL 14 or later as soon as possible to "
+                           "maintain security, performance, and supportability.")
 
 
 def _pg_high_availability_validator(high_availability, standby_availability_zone, zone, tier, single_az, instance):
@@ -901,7 +905,7 @@ def validate_identities(cmd, namespace):
         namespace.identities = [_validate_identity(cmd, namespace, identity) for identity in namespace.identities]
 
 
-def _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_redundant_backup, performance_tier,
+def _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_redundant_backup, performance_tier, tier,
                                supported_storageV2_size, iops, throughput, instance):
     is_create_ssdv2 = storage_type == "PremiumV2_LRS"
     is_update_ssdv2 = instance is not None and instance.storage.type == "PremiumV2_LRS"
@@ -924,6 +928,8 @@ def _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_r
             raise ValidationError("Geo-redundancy is not supported for servers with Premium SSD V2.")
         if performance_tier:
             raise ValidationError("Performance tier is not supported for servers with Premium SSD V2.")
+        if tier and tier.lower() == 'burstable':
+            raise ValidationError("Burstable tier is not supported for servers with Premium SSD V2.")
     else:
         if throughput is not None:
             raise CLIError('Updating throughput is only capable for server created with Premium SSD v2.')
@@ -931,6 +937,13 @@ def _pg_storage_type_validator(storage_type, auto_grow, high_availability, geo_r
             raise CLIError('Updating storage iops is only capable for server created with Premium SSD v2.')
 
 
+def pg_restore_validator(compute_tier, **args):
+    is_ssdv2_enabled = args.get('storage_type', None) == "PremiumV2_LRS"
+
+    if is_ssdv2_enabled and compute_tier.lower() == 'burstable':
+        raise ValidationError("Burstable tier is not supported for servers with Premium SSD V2.")
+
+
 def _pg_authentication_validator(password_auth, is_microsoft_entra_auth_enabled,
                                  admin_name, admin_id, admin_type, instance):
     if instance is None:
@@ -986,7 +999,7 @@ def validate_backup_name(backup_name):
 
 
 def validate_database_name(database_name):
-    if database_name is not None and not re.match(r'^[a-zA-Z_][a-zA-Z0-9_]{0,30}$', database_name):
+    if database_name is not None and not re.match(r'^[a-zA-Z_][\w\-]{0,62}$', database_name):
         raise ValidationError("Database name must begin with a letter (a-z) or underscore (_). "
-                              "Subsequent characters in a name can be letters, digits (0-9), or underscores. "
-                              "Database name length must be less than 32 characters.")
+                              "Subsequent characters in a name can be letters, digits (0-9), hyphens (-), "
+                              "or underscores. Database name length must be less than 64 characters.")
