@@ -56,7 +56,7 @@ def generate_sas(cmd, client, services, resource_types, permission, expiry, star
                          start=start, ip=ip, protocol=protocol, **kwargs)
 
 
-# pylint: disable=too-many-locals, too-many-statements, too-many-branches, unused-argument
+# pylint: disable=too-many-locals, too-many-statements, too-many-branches, unused-argument, line-too-long
 def create_storage_account(cmd, resource_group_name, account_name, sku=None, location=None, kind=None,
                            tags=None, custom_domain=None, encryption_services=None, encryption_key_source=None,
                            encryption_key_name=None, encryption_key_vault=None, encryption_key_version=None,
@@ -78,7 +78,8 @@ def create_storage_account(cmd, resource_group_name, account_name, sku=None, loc
                            enable_nfs_v3=None, subnet=None, vnet_name=None, action='Allow', enable_alw=None,
                            immutability_period_since_creation_in_days=None, immutability_policy_state=None,
                            allow_protected_append_writes=None, public_network_access=None, dns_endpoint_type=None,
-                           enable_smb_oauth=None, zones=None, zone_placement_policy=None):
+                           enable_smb_oauth=None, zones=None, zone_placement_policy=None,
+                           enable_blob_geo_priority_replication=None):
     StorageAccountCreateParameters, Kind, Sku, CustomDomain, AccessTier, Identity, Encryption, NetworkRuleSet = \
         cmd.get_models('StorageAccountCreateParameters', 'Kind', 'Sku', 'CustomDomain', 'AccessTier', 'Identity',
                        'Encryption', 'NetworkRuleSet')
@@ -320,6 +321,10 @@ def create_storage_account(cmd, resource_group_name, account_name, sku=None, loc
         Placement = cmd.get_models('Placement')
         params.placement = Placement(zone_placement_policy=zone_placement_policy)
 
+    if enable_blob_geo_priority_replication is not None:
+        GeoPriorityReplicationStatus = cmd.get_models('GeoPriorityReplicationStatus')
+        params.geo_priority_replication_status = GeoPriorityReplicationStatus(is_blob_enabled=enable_blob_geo_priority_replication)
+
     return scf.storage_accounts.begin_create(resource_group_name, account_name, params)
 
 
@@ -414,7 +419,8 @@ def update_storage_account(cmd, instance, sku=None, tags=None, custom_domain=Non
                            allow_cross_tenant_replication=None, default_share_permission=None,
                            immutability_period_since_creation_in_days=None, immutability_policy_state=None,
                            allow_protected_append_writes=None, public_network_access=None, upgrade_to_storagev2=None,
-                           yes=None, enable_smb_oauth=None, zones=None, zone_placement_policy=None):
+                           yes=None, enable_smb_oauth=None, zones=None, zone_placement_policy=None,
+                           enable_blob_geo_priority_replication=None):
     StorageAccountUpdateParameters, Sku, CustomDomain, AccessTier, Identity, Encryption, NetworkRuleSet, Kind = \
         cmd.get_models('StorageAccountUpdateParameters', 'Sku', 'CustomDomain', 'AccessTier', 'Identity', 'Encryption',
                        'NetworkRuleSet', 'Kind')
@@ -724,6 +730,10 @@ def update_storage_account(cmd, instance, sku=None, tags=None, custom_domain=Non
         Placement = cmd.get_models('Placement')
         params.placement = Placement(zone_placement_policy=zone_placement_policy)
 
+    if enable_blob_geo_priority_replication is not None:
+        GeoPriorityReplicationStatus = cmd.get_models('GeoPriorityReplicationStatus')
+        params.geo_priority_replication_status = GeoPriorityReplicationStatus(is_blob_enabled=enable_blob_geo_priority_replication)
+
     return params
 
 
@@ -1020,15 +1030,18 @@ def list_encryption_scope(client, resource_group_name, account_name,
 # pylint: disable=no-member
 def create_or_policy(cmd, client, account_name, resource_group_name=None, properties=None, source_account=None,
                      destination_account=None, policy_id="default", rule_id=None, source_container=None,
-                     destination_container=None, min_creation_time=None, prefix_match=None, enable_metrics=None):
+                     destination_container=None, min_creation_time=None, prefix_match=None, enable_metrics=None,
+                     priority_replication=None):
     from azure.core.exceptions import HttpResponseError
     ObjectReplicationPolicy = cmd.get_models('ObjectReplicationPolicy')
 
     if properties is None:
         rules = []
-        ObjectReplicationPolicyRule, ObjectReplicationPolicyFilter, ObjectReplicationPolicyPropertiesMetrics = \
+        (ObjectReplicationPolicyRule, ObjectReplicationPolicyFilter, ObjectReplicationPolicyPropertiesMetrics,
+         ObjectReplicationPolicyPropertiesPriorityReplication) = \
             cmd.get_models('ObjectReplicationPolicyRule', 'ObjectReplicationPolicyFilter',
-                           'ObjectReplicationPolicyPropertiesMetrics')
+                           'ObjectReplicationPolicyPropertiesMetrics',
+                           'ObjectReplicationPolicyPropertiesPriorityReplication')
         if source_container and destination_container:
             rule = ObjectReplicationPolicyRule(
                 rule_id=rule_id,
@@ -1040,7 +1053,9 @@ def create_or_policy(cmd, client, account_name, resource_group_name=None, proper
         or_policy = ObjectReplicationPolicy(source_account=source_account,
                                             destination_account=destination_account,
                                             rules=rules,
-                                            metrics=ObjectReplicationPolicyPropertiesMetrics(enabled=enable_metrics))
+                                            metrics=ObjectReplicationPolicyPropertiesMetrics(enabled=enable_metrics),
+                                            priority_replication=ObjectReplicationPolicyPropertiesPriorityReplication(
+                                                enabled=priority_replication))
     else:
         or_policy = properties
     try:
@@ -1055,8 +1070,10 @@ def create_or_policy(cmd, client, account_name, resource_group_name=None, proper
         raise ex
 
 
+# pylint: disable=line-too-long
 def update_or_policy(cmd, client, parameters, resource_group_name, account_name, object_replication_policy_id=None,
-                     properties=None, source_account=None, destination_account=None, enable_metrics=None):
+                     properties=None, source_account=None, destination_account=None, enable_metrics=None,
+                     priority_replication=None):
 
     if source_account is not None:
         parameters.source_account = source_account
@@ -1072,6 +1089,11 @@ def update_or_policy(cmd, client, parameters, resource_group_name, account_name,
         ObjectReplicationPolicyPropertiesMetrics = cmd.get_models('ObjectReplicationPolicyPropertiesMetrics')
         parameters.metrics = ObjectReplicationPolicyPropertiesMetrics(enabled=enable_metrics)
 
+    if priority_replication is not None:
+        ObjectReplicationPolicyPropertiesPriorityReplication = (
+            cmd.get_models('ObjectReplicationPolicyPropertiesPriorityReplication'))
+        parameters.priority_replication = ObjectReplicationPolicyPropertiesPriorityReplication(enabled=priority_replication)
+
     return client.create_or_update(resource_group_name=resource_group_name, account_name=account_name,
                                    object_replication_policy_id=object_replication_policy_id, properties=parameters)
 
