@@ -14,7 +14,7 @@ from azure.cli.command_modules.vm._client_factory import (cf_vm,
                                                           cf_log_analytics_data_plane,
                                                           cf_capacity_reservation_groups, cf_capacity_reservations,
                                                           cf_restore_point,
-                                                          cf_restore_point_collection, cf_community_gallery)
+                                                          cf_community_gallery)
 from azure.cli.command_modules.vm._format import (
     transform_ip_addresses, transform_vm, transform_vm_create_output, transform_vm_usage_list, transform_vm_list,
     transform_disk_create_table_output, transform_sku_for_table_output, transform_disk_show_table_output,
@@ -199,8 +199,7 @@ def load_command_table(self, _):
     )
 
     restore_point_collection = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#RestorePointCollectionsOperations.{}',
-        client_factory=cf_restore_point_collection
+        operations_tmpl='azure.mgmt.compute.operations#RestorePointCollectionsOperations.{}'
     )
 
     community_gallery_sdk = CliCommandType(
@@ -562,9 +561,5 @@ def load_command_table(self, _):
         g.custom_command('create', 'restore_point_create', supports_no_wait=True)
         g.wait_command('wait')
 
-    with self.command_group('restore-point collection', restore_point_collection, min_api='2021-03-01',
-                            client_factory=cf_restore_point_collection) as g:
+    with self.command_group('restore-point collection', restore_point_collection) as g:
         g.custom_show_command('show', 'restore_point_collection_show')
-        g.custom_command('create', 'restore_point_collection_create')
-        g.custom_command('update', 'restore_point_collection_update')
-        g.wait_command('wait')
